@@ -3,6 +3,7 @@ import logging
 import socket
 import traceback
 import xml.etree.ElementTree as ET
+from functools import partial
 from typing import Any, Callable, Dict, List, Optional, Type, Union
 
 from . import introspection as intr
@@ -713,34 +714,35 @@ class BaseMessageBus:
         if err:
             raise err
 
+    def _reply_notify(
+        self,
+        msg: Message,
+        callback: Optional[Callable[[Optional[Message], Optional[Exception]], None]],
+        reply: Optional[Message],
+        err: Optional[Exception],
+    ) -> None:
+        """Callback on reply."""
+        if reply and msg.destination and reply.sender:
+            self._name_owners[msg.destination] = reply.sender
+        callback(reply, err)
+
     def _call(
         self,
         msg: Message,
         callback: Optional[Callable[[Optional[Message], Optional[Exception]], None]],
-        check_callback: bool = True,
     ) -> None:
-        if check_callback:
-            BaseMessageBus._check_callback_type(callback)
-
         if not msg.serial:
             msg.serial = self.next_serial()
 
-        no_reply_expected = _expects_reply(msg) is False
+        no_reply_expected = not _expects_reply(msg)
         # Make sure the return reply handler is installed
         # before sending the message to avoid a race condition
         # where the reply is lost in case the backend can
         # send it right away.
         if not no_reply_expected:
-
-            def _reply_notify(
-                reply: Optional[Message], err: Optional[Exception]
-            ) -> None:
-                """Callback on reply."""
-                if reply and msg.destination and reply.sender:
-                    self._name_owners[msg.destination] = reply.sender
-                callback(reply, err)
-
-            self._method_return_handlers[msg.serial] = _reply_notify
+            self._method_return_handlers[msg.serial] = partial(
+                self._reply_notify, msg, callback
+            )
 
         self.send(msg)
 
@@ -863,67 +865,64 @@ class BaseMessageBus:
                 return_handler(msg, None)
             del self._method_return_handlers[msg.reply_serial]
 
+    def _callback_method_handler(
+        self,
+        interface: ServiceInterface,
+        method: _Method,
+        msg: Message,
+        send_reply: Callable[[Message], None],
+    ) -> None:
+        """This is the callback that will be called when a method call is."""
+        args = ServiceInterface._c_msg_body_to_args(msg) if msg.unix_fds else msg.body
+        result = method.fn(interface, *args)
+        if send_reply is BLOCK_UNEXPECTED_REPLY or _expects_reply(msg) is False:
+            return
+        body, fds = ServiceInterface._c_fn_result_to_body(
+            result,
+            signature_tree=method.out_signature_tree,
+            replace_fds=self._negotiate_unix_fd,
+        )
+        send_reply(
+            Message(
+                message_type=MessageType.METHOD_RETURN,
+                reply_serial=msg.serial,
+                destination=msg.sender,
+                signature=method.out_signature,
+                body=body,
+                unix_fds=fds,
+            )
+        )
+
     def _make_method_handler(
         self, interface: ServiceInterface, method: _Method
     ) -> Callable[[Message, Callable[[Message], None]], None]:
-        method_fn = method.fn
-        out_signature_tree = method.out_signature_tree
-        negotiate_unix_fd = self._negotiate_unix_fd
-        out_signature = method.out_signature
-        message_type_method_return = MessageType.METHOD_RETURN
-        msg_body_to_args = ServiceInterface._msg_body_to_args
-        fn_result_to_body = ServiceInterface._fn_result_to_body
-
-        def _callback_method_handler(
-            msg: Message, send_reply: Callable[[Message], None]
-        ) -> None:
-            """This is the callback that will be called when a method call is."""
-            args = msg_body_to_args(msg) if msg.unix_fds else msg.body
-            result = method_fn(interface, *args)
-            if send_reply is BLOCK_UNEXPECTED_REPLY or _expects_reply(msg) is False:
-                return
-            body, fds = fn_result_to_body(
-                result,
-                signature_tree=out_signature_tree,
-                replace_fds=negotiate_unix_fd,
-            )
-            send_reply(
-                Message(
-                    message_type=message_type_method_return,
-                    reply_serial=msg.serial,
-                    destination=msg.sender,
-                    signature=out_signature,
-                    body=body,
-                    unix_fds=fds,
-                )
-            )
-
-        return _callback_method_handler
+        return partial(self._callback_method_handler, interface, method)
 
     def _find_message_handler(
         self, msg: _Message
     ) -> Optional[Callable[[Message, Callable[[Message], None]], None]]:
-        if (
-            msg.interface == "org.freedesktop.DBus.Introspectable"
-            and msg.member == "Introspect"
-            and msg.signature == ""
-        ):
-            return self._default_introspect_handler
+        if msg.interface.startswith("org.freedesktop.DBus."):
+            if (
+                msg.interface == "org.freedesktop.DBus.Introspectable"
+                and msg.member == "Introspect"
+                and msg.signature == ""
+            ):
+                return self._default_introspect_handler
 
-        if msg.interface == "org.freedesktop.DBus.Properties":
-            return self._default_properties_handler
+            if msg.interface == "org.freedesktop.DBus.Properties":
+                return self._default_properties_handler
 
-        if msg.interface == "org.freedesktop.DBus.Peer":
-            if msg.member == "Ping" and msg.signature == "":
-                return self._default_ping_handler
-            elif msg.member == "GetMachineId" and msg.signature == "":
-                return self._default_get_machine_id_handler
+            if msg.interface == "org.freedesktop.DBus.Peer":
+                if msg.member == "Ping" and msg.signature == "":
+                    return self._default_ping_handler
+                elif msg.member == "GetMachineId" and msg.signature == "":
+                    return self._default_get_machine_id_handler
 
-        if (
-            msg.interface == "org.freedesktop.DBus.ObjectManager"
-            and msg.member == "GetManagedObjects"
-        ):
-            return self._default_get_managed_objects_handler
+            if (
+                msg.interface == "org.freedesktop.DBus.ObjectManager"
+                and msg.member == "GetManagedObjects"
+            ):
+                return self._default_get_managed_objects_handler
 
         msg_path = msg.path
         if msg_path:
@@ -931,7 +930,7 @@ class BaseMessageBus:
             if not interfaces:
                 return None
             for interface in interfaces:
-                methods = ServiceInterface._get_methods(interface)
+                methods = ServiceInterface._c_get_methods(interface)
                 for method in methods:
                     if method.disabled:
                         continue
@@ -941,7 +940,7 @@ class BaseMessageBus:
                         and msg.member == method.name
                         and msg.signature == method.in_signature
                     ):
-                        return ServiceInterface._get_handler(interface, method, self)
+                        return ServiceInterface._c_get_handler(interface, method, self)
 
         return None
 
@@ -986,7 +985,6 @@ class BaseMessageBus:
                 member="GetMachineId",
             ),
             reply_handler,
-            check_callback=False,
         )
 
     def _default_get_managed_objects_handler(
@@ -1213,7 +1211,6 @@ class BaseMessageBus:
                 body=[self._name_owner_match_rule],
             ),
             add_match_notify,
-            check_callback=False,
         )
 
     def _add_match_rule(self, match_rule):
@@ -1247,7 +1244,6 @@ class BaseMessageBus:
                 body=[match_rule],
             ),
             add_match_notify,
-            check_callback=False,
         )
 
     def _remove_match_rule(self, match_rule):
@@ -1286,5 +1282,4 @@ class BaseMessageBus:
                 body=[match_rule],
             ),
             remove_match_notify,
-            check_callback=False,
         )
